psychopy_ext.exp.SVG — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.SVG

class `psychopy_ext.exp.` `SVG`(win, filename='image')
  `__init__`(win, filename='image')

  Methods

  `__init__`(win[, filename]) |
  `color2attr`(stim, attr[, color, colorSpace, ...]) |
  `color2rgb255`(stim[, color, colorSpace]) | Convert color to RGB255 while adding contrast
  `get_pos`(stim[, pos, offset]) |
  `get_size`(stim[, size]) |
  `open`(filename) |
  `save`() |
  `write`(stim) |